InitRequest class

Information communicated to the platform implementation when creating a new player instance.

Constructors

InitRequest({required String id, AudioLoadConfigurationMessage? audioLoadConfiguration, List<AudioEffectMessage> androidAudioEffects = const [], List<AudioEffectMessage> darwinAudioEffects = const [], AndroidAudioOffloadPreferencesMessage? androidAudioOffloadPreferences, bool? androidOffloadSchedulingEnabled, bool useLazyPreparation = true})

Properties

androidAudioEffects → List<AudioEffectMessage>
final
androidAudioOffloadPreferences → AndroidAudioOffloadPreferencesMessage?
final
androidOffloadSchedulingEnabled → bool?
final
audioLoadConfiguration → AudioLoadConfigurationMessage?
final
darwinAudioEffects → List<AudioEffectMessage>
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useLazyPreparation → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited