PlaybackEventMessage class

A playback event communicated from the platform implementation to the Flutter plugin.

Constructors

PlaybackEventMessage({required ProcessingStateMessage processingState, required DateTime updateTime, required Duration updatePosition, required Duration bufferedPosition, required Duration? duration, required IcyMetadataMessage? icyMetadata, required int? currentIndex, required int? androidAudioSessionId, int? errorCode, String? errorMessage})

Properties

androidAudioSessionId → int?
final
bufferedPosition → Duration
final
currentIndex → int?
final
duration → Duration?
final
errorCode → int?
final
errorMessage → String?
final
hashCode → int
The hash code for this object.
no setterinherited
icyMetadata → IcyMetadataMessage?
final
processingState → ProcessingStateMessage
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatePosition → Duration
final
updateTime → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map map) → PlaybackEventMessage