MethodChannelAudioPlayer class

An implementation of AudioPlayerPlatform that uses method channels.

Inheritance

Constructors

MethodChannelAudioPlayer(String id)

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
finalinherited
playbackEventMessageStream → Stream<PlaybackEventMessage>
A broadcast stream of playback events.
no setteroverride
playerDataMessageStream → Stream<PlayerDataMessage>
A broadcast stream of data updates.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

androidEqualizerBandSetGain(AndroidEqualizerBandSetGainRequest request) → Future<AndroidEqualizerBandSetGainResponse>
Sets the gain for an Android equalizer band.
override
androidEqualizerGetParameters(AndroidEqualizerGetParametersRequest request) → Future<AndroidEqualizerGetParametersResponse>
Gets the Android equalizer parameters.
override
androidLoudnessEnhancerSetTargetGain(AndroidLoudnessEnhancerSetTargetGainRequest request) → Future<AndroidLoudnessEnhancerSetTargetGainResponse>
Sets the target gain on the Android loudness enhancer.
override
audioEffectSetEnabled(AudioEffectSetEnabledRequest request) → Future<AudioEffectSetEnabledResponse>
Changes the enabled status of an audio effect.
override
concatenatingInsertAll(ConcatenatingInsertAllRequest request) → Future<ConcatenatingInsertAllResponse>
Inserts audio sources into the given concatenating audio source.
override
concatenatingMove(ConcatenatingMoveRequest request) → Future<ConcatenatingMoveResponse>
Moves an audio source within a concatenating audio source.
override
concatenatingRemoveRange(ConcatenatingRemoveRangeRequest request) → Future<ConcatenatingRemoveRangeResponse>
Removes audio sources from the given concatenating audio source.
override
dispose(DisposeRequest request) → Future<DisposeResponse>
This method has been superseded by JustAudioPlatform.disposePlayer. For backward compatibility, this method will still be called as a fallback if JustAudioPlatform.disposePlayer is not implemented.
override
load(LoadRequest request) → Future<LoadResponse>
Loads an audio source.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause(PauseRequest request) → Future<PauseResponse>
Pauses playback.
override
play(PlayRequest request) → Future<PlayResponse>
Plays the current audio source at the current index and position.
override
seek(SeekRequest request) → Future<SeekResponse>
Seeks to the given index and position.
override
setAllowsExternalPlayback(SetAllowsExternalPlaybackRequest request) → Future<SetAllowsExternalPlaybackResponse>
On iOS and macOS, sets the allowsExternalPlayback option, and does nothing on other platforms.
override
setAndroidAudioAttributes(SetAndroidAudioAttributesRequest request) → Future<SetAndroidAudioAttributesResponse>
On Android, sets the audio attributes, and does nothing on other platforms.
override
setAutomaticallyWaitsToMinimizeStalling(SetAutomaticallyWaitsToMinimizeStallingRequest request) → Future<SetAutomaticallyWaitsToMinimizeStallingResponse>
On iOS and macOS, sets the automaticallyWaitsToMinimizeStalling option, and does nothing on other platforms.
override
setCanUseNetworkResourcesForLiveStreamingWhilePaused(SetCanUseNetworkResourcesForLiveStreamingWhilePausedRequest request) → Future<SetCanUseNetworkResourcesForLiveStreamingWhilePausedResponse>
On iOS and macOS, sets the canUseNetworkResourcesForLiveStreamingWhilePaused option, and does nothing on other platforms.
override
setLoopMode(SetLoopModeRequest request) → Future<SetLoopModeResponse>
Sets the loop mode.
override
setPitch(SetPitchRequest request) → Future<SetPitchResponse>
Changes the pitch.
override
setPreferredPeakBitRate(SetPreferredPeakBitRateRequest request) → Future<SetPreferredPeakBitRateResponse>
On iOS and macOS, sets the preferredPeakBitRate option, and does nothing on other platforms.
override
setShuffleMode(SetShuffleModeRequest request) → Future<SetShuffleModeResponse>
Sets the shuffle mode.
override
setShuffleOrder(SetShuffleOrderRequest request) → Future<SetShuffleOrderResponse>
Sets the shuffle order.
override
setSkipSilence(SetSkipSilenceRequest request) → Future<SetSkipSilenceResponse>
Sets skipSilence to true/false.
override
setSpeed(SetSpeedRequest request) → Future<SetSpeedResponse>
Changes the playback speed.
override
setVolume(SetVolumeRequest request) → Future<SetVolumeResponse>
Changes the volume.
override
setWebCrossOrigin(SetWebCrossOriginRequest request) → Future<SetWebCrossOriginResponse>
Sets the 'crossOrigin' attribute on the web audio element.
inherited
setWebSinkId(SetWebSinkIdRequest request) → Future<SetWebSinkIdResponse>
Sets a specific device output id on the web audio element.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited